@@ -3,13 +3,12 @@
 
 use std::{convert::TryInto, fs, io, path::PathBuf, str::FromStr};
 
-use hex::FromHex;
 use serde::{self, Deserialize};
 
 use casper_execution_engine::core::engine_state::executable_deploy_item::ExecutableDeployItem;
 use casper_hashing::Digest;
 use casper_node::{
-    crypto::{self, AsymmetricKeyExt},
+    crypto::AsymmetricKeyExt,
     types::{DeployHash, TimeDiff, Timestamp},
 };
 use casper_types::{
@@ -21,7 +20,7 @@ use crate::{
     cl_type,
     deploy::DeployParams,
     error::{Error, Result},
-    help, PaymentStrParams, SessionStrParams,
+    help, map_hashing_error, PaymentStrParams, SessionStrParams,
 };
 
 pub(super) fn none_if_empty(value: &'_ str) -> Option<&'_ str> {
@@ -60,10 +59,8 @@ fn gas_price(value: &str) -> Result<u64> {
 fn dependencies(values: &[&str]) -> Result<Vec<DeployHash>> {
     let mut hashes = Vec::with_capacity(values.len());
     for value in values {
-        let digest = Digest::from_hex(value).map_err(|error| Error::CryptoError {
-            context: "dependencies",
-            error: crypto::Error::FromHex(error),
-        })?;
+        let digest =
+            Digest::from_hex(value).map_err(|error| map_hashing_error(error)("dependencies"))?;
         hashes.push(DeployHash::new(digest))
     }
     Ok(hashes)
@@ -142,16 +139,55 @@ mod arg_simple {
 /// Handles providing the arg for and retrieval of complex session and payment args. These are read
 /// in from a file.
 mod args_complex {
+    use std::{
+        fmt::{self, Formatter},
+        result::Result as StdResult,
+    };
+
+    use serde::de::{Deserializer, Error as SerdeError, Visitor};
+
+    use casper_types::checksummed_hex;
+
     use super::*;
 
     #[derive(Debug, Deserialize)]
     #[serde(rename_all = "snake_case")]
     enum DeployArgValue {
         /// Contains `CLValue` serialized into bytes in base16 form.
-        #[serde(deserialize_with = "hex::deserialize")]
+        #[serde(deserialize_with = "deserialize_raw_bytes")]
         RawBytes(Vec<u8>),
     }
 
+    fn deserialize_raw_bytes<'de, D: Deserializer<'de>>(
+        deserializer: D,
+    ) -> StdResult<Vec<u8>, D::Error> {
+        struct HexStrVisitor;
+
+        impl<'de> Visitor<'de> for HexStrVisitor {
+            type Value = Vec<u8>;
+
+            fn expecting(&self, formatter: &mut Formatter) -> fmt::Result {
+                write!(formatter, "a hex encoded string")
+            }
+
+            fn visit_str<E: SerdeError>(
+                self,
+                hex_encoded_input: &str,
+            ) -> StdResult<Self::Value, E> {
+                checksummed_hex::decode(hex_encoded_input).map_err(SerdeError::custom)
+            }
+
+            fn visit_borrowed_str<E: SerdeError>(
+                self,
+                hex_encoded_input: &'de str,
+            ) -> StdResult<Self::Value, E> {
+                checksummed_hex::decode(hex_encoded_input).map_err(SerdeError::custom)
+            }
+        }
+
+        deserializer.deserialize_str(HexStrVisitor)
+    }
+
     #[derive(Debug, Deserialize)]
     #[serde(rename_all = "snake_case")]
     struct DeployArg {
